# deuna_checkout_widget

[![style: very good analysis][very_good_analysis_badge]][very_good_analysis_link]
[![License: GPL v3][license_badge]][license_link]

Una vez que hayas recibido los [API Keys](https://duna.readme.io/docs/api-keys)
de DEUNA, instala el plugin de la siguiente manera:

Agrega la dependencia en `pubspec.yaml`:

```yaml
dependencies:
  deuna_checkout_widget: ^ultima_version
```

Revisa la última versión en [pub.dev](https://pub.dev/packages/deuna_checkout_widget).

## Android

Configura el `minSdkVersion` al valor correcto en `android/app/build.gradle`:

```
 android {
     defaultConfig {
         minSdkVersion 20
     }
 }
```

## iOS

No hay nada que hacer. Ya está listo para ser usado.

## Usage

Importar el plugin `deuna_checkout_widget`:

```dart
import 'package:deuna_checkout_widget/deuna_checkout_widget.dart';
```

En la raíz de la aplicación, agregar la configuración para el plugin:

```dart
DeUnaCheckoutConfiguration(
    data: const DeUnaCheckoutData(
      env: DeUnaCheckoutEnv.stg, // El valor por defecto es DeUnaCheckoutEnv.prod
      apiKey: 'YOUR_API_KEY',
      analyticsConfig: AnalyticsConfig( // analyticsConfig es un campo opcional
        amplitudeKeyId: 'AMPLITUDE_KEY_ID', // Obligatorio
        googleTagManagerKeyId: 'GOOGLE_TAG_MANAGER_KEY_ID', // opcional
          sessionId: 'SESSION_ID', // opcional
        ),
    ),
    child: MaterialApp(
      child: ...
    ),
);
```

Luego de obtener el token de la orden (`orderToken`), puedes llamar al widget:

```dart
DeUnaCheckout(
  orderToken: orderToken,
),
```

## Ejemplo

El siguiente ejemplo asume que ya se ha generado el `orderToken`:

```dart
import 'package:deuna_checkout_widget/deuna_checkout_widget.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return DeUnaCheckoutConfiguration(
      // Set `data` with your configuration data.
      data: const DeUnaCheckoutData(
        env: DeUnaCheckoutEnv.stg, // default value is prod
        apiKey: 'YOUR_API_KEY',
      ),
      child: MaterialApp(
        title: 'Flutter Demo',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        home: const MyHomePage(title: 'DEUNA Checkout Demo'),
      ),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  void openCheckout() {
    Navigator.push<void>(
      context,
      MaterialPageRoute(
        builder: (context) => const CheckoutExample(
          orderToken: 'YOUR_ORDER_TOKEN',
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: const <Widget>[
            Text(
              'Press the action button to open the checkout',
            ),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: openCheckout,
        tooltip: 'Open Checkout',
        child: const Icon(Icons.add),
      ),
    );
  }
}

class CheckoutExample extends StatelessWidget {
  const CheckoutExample({
    Key? key,
    required this.orderToken,
  }) : super(key: key);

  final String orderToken;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('DEUNA Checkout Widget'),
      ),
      body: Center(
        child: DeUnaCheckout(
          orderToken: orderToken,
        ),
      ),
    );
  }
}
```

[license_badge]: https://img.shields.io/badge/License-GPLv3-blue.svg
[license_link]: https://www.gnu.org/licenses/gpl-3.0
[very_good_analysis_badge]: https://img.shields.io/badge/style-very_good_analysis-B22C89.svg
[very_good_analysis_link]: https://pub.dev/packages/very_good_analysis
