import 'package:deuna_checkout_widget/src/deuna_checkout_configuration.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testWidgets(
      'deuna checkout configuration throws '
      'an error when it is not provided', (tester) async {
    FlutterError? error;
    await tester.pumpWidget(
      Builder(
        builder: (context) {
          try {
            DeUnaCheckoutConfiguration.of(context);
            fail('There must not be a configuration');
          } catch (err) {
            if (err is FlutterError) {
              error = err;
            }
          }
          return const Offstage();
        },
      ),
    );
    expect(error, isNotNull);
  });

  testWidgets('deuna checkout configuration is well read', (tester) async {
    const data = DeUnaCheckoutData(apiKey: 'apiKey-test');
    late DeUnaCheckoutData readData;
    await tester.pumpWidget(
      DeUnaCheckoutConfiguration(
        data: data,
        child: Builder(
          builder: (context) {
            readData = DeUnaCheckoutConfiguration.of(context);
            return const Offstage();
          },
        ),
      ),
    );
    expect(readData, same(data));
  });

  testWidgets('deuna checkout configuration is well read', (tester) async {
    const data1 = DeUnaCheckoutData(apiKey: 'apiKey-test1');
    const data2 = DeUnaCheckoutData(apiKey: 'apiKey-test2');

    expect(data1, isNot(data2));
    final data = ValueNotifier(data1);

    late DeUnaCheckoutData readData;
    await tester.pumpWidget(
      ValueListenableBuilder<DeUnaCheckoutData>(
        valueListenable: data,
        builder: (context, data, _) => DeUnaCheckoutConfiguration(
          data: data,
          child: Builder(
            builder: (context) {
              readData = DeUnaCheckoutConfiguration.of(context);
              return const Offstage();
            },
          ),
        ),
      ),
    );
    expect(readData, same(data1));

    data.value = data2;
    await tester.pump();
    expect(readData, same(data2));
  });
}
